@@ -1,4 +1,7 @@
-from openfisca_tools.microsimulation import Microsimulation
+from openfisca_tools.microsimulation import (
+    Microsimulation,
+    GeneralMicrosimulation,
+)
 from openfisca_tools.hypothetical import IndividualSim
 from openfisca_tools.testing import generate_tests
 from openfisca_tools.model_api import *
